"""
Insert missed grozper data

Revision ID: fdf3875930d9
Revises: 658ae66a2716
Create Date: 2018-11-27 14:09:27.397850

"""

import csv
from datetime import datetime
import json
import os
import tempfile

import boto3

from stumpf.models import db, FactSchema, PROV_EXTERNAL_PROCESS_CREATED_FACT, Provenance


# revision identifiers, used by Alembic.
revision = 'fdf3875930d9'
down_revision = '658ae66a2716'
branch_labels = None
depends_on = None


def upgrade():
    fact_schema = FactSchema()
    meta = {
        'batch': f'migrate-{datetime.now().isoformat()}',
        'migration': True
    }

    with tempfile.TemporaryDirectory() as tmpdirname:

        # Download csv from s3. Requires boto credentials to be set.
        BUCKET_NAME = 'diva-stumpf-migration-data'
        KEY = 'data-1543333571698.csv'
        path = os.path.join(tmpdirname, KEY)
        s3 = boto3.resource('s3')
        s3.Bucket(BUCKET_NAME).download_file(KEY, path)

        with open(path, newline='') as csvfile:
            reader = csv.DictReader(csvfile)
            for row in reader:
                fact = fact_schema.load(
                    dict(id=row['id'],
                         fact=json.loads(row['fact']),
                         video_id=row['video_id'],
                         schema=row['schema'],
                         frame_range=[int(row['frame_range_from']), int(row['frame_range_to'])]))
                provenance = Provenance(fact=fact, meta=meta,
                                        relationship=PROV_EXTERNAL_PROCESS_CREATED_FACT)
                db.session.add_all([fact, provenance])

    db.session.commit()


def downgrade():
    pass
